%global _hardened_build 1

# Make reproducible builds possible
%global source_date_epoch_from_changelog 0
%global clamp_mtime_to_source_date_epoch 1
%global use_source_date_epoch_as_buildtime 1
%define _buildhost apkg

%{!?_syprefix: %define _syprefix /opt/symas }
%{!?_etcfix: %define _etcfix %{_syprefix}/etc }
%{!?_sylibdir: %define _sylibdir %{_syprefix}/lib }
%{!?_varfix: %define _varfix /var/symas }

%if 0%{?suse_version}
# We don't seem to have %{dist} in SUSEs, define our own
%{!?dist: %define dist .sles7 }
%endif

Summary: Symas's Heimdal Kerberos build
Name: symas-heimdal
Version: 7.8.0
Release: 7%{?dist}
License: BSD
Source: %{name}-v%{version}.tar.xz

URL: https://github.com/heimdal/
VCS: https://git.symas.net/symas-public/heimdal.git

# Apparently distro setup should fill this in, but can't see where,
# Fake ours from dist and strip the leading dot
Distribution: %(echo %{?dist} | tr -d .)

AutoReqProv: no
# BuildRequires one at a time, microdnf doesn't support comma separated dependencies
BuildRequires: symas-buildtools >= 1.0.4
BuildRequires: gcc
BuildRequires: make
BuildRequires: automake
BuildRequires: libtool
BuildRequires: autoconf
BuildRequires: byacc
BuildRequires: flex
BuildRequires: sqlite-devel
BuildRequires: ncurses-devel
BuildRequires: python3
BuildRequires: texinfo
BuildRequires: unzip
%if 0%{?suse_version}
BuildRequires: perl
BuildRequires: libdb-4_8-devel
%else
BuildRequires: perl-interpreter
BuildRequires: libdb-devel
%endif
BuildRequires: perl(JSON)

Patch0: CVE-2022-45142-gsskrb5-fix-accidental-logic-inversio.patch

%description
The Symas Heimdal Kerberos build for additional encryption services

%package libs
Summary: Heimdal Libaries
AutoReqProv: no
%if 0%{?suse_version}
Requires: libncurses6, libsqlite3-0
%else
%if 0%{?centos_ver} && 0%{?centos_ver} == 7
Requires: sqlite
%else
Requires: sqlite-libs
%endif
Requires: ncurses-libs
%endif

%description libs
The symas-heimdal-libs package contains the heimdal libraries

%package devel
Summary: Heimdal Development
AutoReqProv: no
Requires: symas-heimdal-libs = %{version}-%{release}

%description devel
The symas-heimdal-devel package contains the linking libraries and include files

%prep
%setup -qn %{name}-v%{version}
%patch0 -p1

%build
autoreconf -f -i
%if 0%{?suse_version}
LDFLAGS="-L%{_sylibdir} -Wl,-rpath,%{_sylibdir}" \
%else
LDFLAGS="%{__global_ldflags} -L%{_sylibdir} -Wl,-rpath,%{_sylibdir}" \
%endif
CFLAGS="%{optflags} -D_REENTRANT" \
CXXFLAGS="%{optflags} -D_REENTRANT" \
CPPFLAGS=-I%{_syprefix}/include \
./configure --prefix=%{_syprefix} \
    --sysconfdir=%{_etcfix}/heimdal \
    --localstatedir=%{_varfix} \
    --libexecdir=%{_sylibdir} \
    --datadir=%{_varfix} \
    --enable-shared \
    --enable-pthread-support \
    --disable-berkeley-db \
    --disable-ndbm-db \
    --disable-afs-support \
    --without-readline \
    --without-openldap \
    --without-hesiod \
    --with-sqlite3=/usr \
    --enable-static=no \
    --without-openssl

make -C include
make -C lib/roken
make -C lib/vers
make -C lib/com_err
make -C lib/base
make -C lib/asn1
make -C lib/libedit
make -C lib/sl
make -C lib/hcrypto
make -C lib/wind
make -C lib/hx509
make -C lib/ipc
make -C lib/krb5
make -C lib/ntlm
make -C lib/gssapi
make -C lib/hdb
make -C lib/kadm5

%install
make -C include install DESTDIR=%{buildroot}
make -C lib/base install DESTDIR=%{buildroot}
make -C lib/roken install DESTDIR=%{buildroot}
make -C lib/com_err install DESTDIR=%{buildroot}
make -C lib/asn1 install DESTDIR=%{buildroot}
make -C lib/libedit install DESTDIR=%{buildroot}
make -C lib/sl install DESTDIR=%{buildroot}
make -C lib/hcrypto install DESTDIR=%{buildroot}
make -C lib/wind install DESTDIR=%{buildroot}
make -C lib/hx509 install DESTDIR=%{buildroot}
make -C lib/ipc install DESTDIR=%{buildroot}
make -C lib/krb5 install DESTDIR=%{buildroot}
make -C lib/ntlm install DESTDIR=%{buildroot}
make -C lib/hdb install DESTDIR=%{buildroot}
make -C lib/kadm5 install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_syprefix}/share/man/cat5/mech
mkdir -p %{buildroot}%{_syprefix}/share/man/man5/mech
mkdir -p %{buildroot}%{_syprefix}/share/doc/heimdal
make -C lib/gssapi install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_syprefix}/bin
rm -rf %{buildroot}%{_syprefix}/libexec
rm -rf %{buildroot}%{_syprefix}/sbin
rm -rf %{buildroot}%{_syprefix}/share/man/man7
rm -rf %{buildroot}%{_syprefix}/share/man/man8
rm -f %{buildroot}%{_syprefix}/share/man/man5/mech.5
rm -f %{buildroot}%{_syprefix}/share/man/man5/qop.5
rm -f %{buildroot}%{_sylibdir}/*.la
rm -rf %{buildroot}%{_sylibdir}/heimdal*
rm -f %{buildroot}%{_sylibdir}/ipropd-master
rm -f %{buildroot}%{_sylibdir}/ipropd-slave
install -m 0644 ChangeLog %{buildroot}%{_syprefix}/share/doc/heimdal
install -m 0644 LICENSE %{buildroot}%{_syprefix}/share/doc/heimdal
install -m 0644 NEWS %{buildroot}%{_syprefix}/share/doc/heimdal
install -m 0644 README %{buildroot}%{_syprefix}/share/doc/heimdal

%check
make -j1 check VERBOSE=1

%files libs
%defattr(-,root,root)
%{_sylibdir}/*.so.*
%{_syprefix}/share/man/man5
%{_syprefix}/share/doc/heimdal

%files devel
%defattr(-,root,root)
%{_sylibdir}/*.so
%{_syprefix}/include
%{_syprefix}/share/man/man3

%changelog
* Wed Jun 05 2024 Symas Support <support@symas.com> - 7.8.0-7
- Switch to apkg for packaging
- Apply fix for CVE-2022-3437
* Mon Oct 30 2023 Symas Support <support@symas.com> - 7.8.0-5
- enable tests
- version 7.8.0-5
* Tue Jul 25 2023 Symas Support <support@symas.com> - 7.8.0-4
- Rebuilding without openssl support 7.8.0-4
* Wed May 31 2023 Symas Support <support@symas.com> - 7.8.0-3
- Rebuilding with OpenSSL3 support 7.8.0-3
* Thu Jan 19 2023 Symas Support <support@symas.com> - 7.8.0-2
- Hardened build in spec file
* Fri Dec 16 2022 Symas Support <support@symas.com> - 7.8.0-1
- Heimdal 7.8.0-1 release bits
* Thu Sep 8 2022 Symas Support <support@symas.com> - 7.7.0-6
- Add patch for upstream issue#431 lib/ipc: client double close of socket file descriptor
* Tue Nov 16 2021 Symas Support <support@symas.com> - 7.7.0-5
- Packaging ChangeLog, LICENSE, NEWS, and README files
* Wed Jun 09 2021 Symas Support <support@symas.com> - 7.7.0-4
- Add patch for upstream issue#776 - Fix ASN1 OID for SHA-384
* Mon May 24 2021 Symas Support <support@symas.com> - 7.7.0-3
- Update paths for odd Symas Gold locations
* Tue May 11 2021 Symas Support <support@symas.com> - 7.7.0-2
- FHS fixups
* Tue Apr 6 2021 Symas Support <support@symas.com> - 7.7.0-1
- initial packaging
